GeofenceRegion class
Constructors
- GeofenceRegion({required String id, required double latitude, required double longitude, required double radiusMeters, GeofenceCallback? onEnter, GeofenceCallback? onExit})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isInside ↔ bool
-
getter/setter pair
- latitude → double
-
final
- longitude → double
-
final
- onEnter → GeofenceCallback?
-
final
- onExit → GeofenceCallback?
-
final
- radiusMeters → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited