SmartConfig class
Configuration options for SmartLocation.
Constructors
- SmartConfig({SmartAccuracy accuracy = SmartAccuracy.balanced, RouteProviderType routeProvider = RouteProviderType.google, String? apiKey, bool debugMode = false, SmartNotificationOptions? backgroundNotification})
-
const
Properties
- accuracy → SmartAccuracy
-
Default accuracy for location requests.
final
- apiKey → String?
-
API Key for the chosen provider.
final
- backgroundNotification → SmartNotificationOptions?
-
Custom notification for background tracking.
final
- debugMode → bool
-
Whether to show debug logs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeProvider → RouteProviderType
-
Whether to use Google Directions, Mapbox, etc.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited