SmartMarker class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
followRoute({required SmartRoute route, Duration stepDuration = const Duration(milliseconds: 1000), double speedKmph = 40.0})
→ Stream<LatLng>
-
Simulates movement along a route.
Returns a stream of LatLng positions.