SmartPolyline class

Constructors

SmartPolyline()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String id, required SmartRoute route, Color color = const Color(0xFF2196F3), int width = 5}) → Polyline
Returns a Polyline object ready for Google Maps.