SmartPosition class
A universal position model that abstracts away the underlying platform specifics.
Constructors
Properties
- accuracy → double
-
final
- altitude → double
-
final
- bearing → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMocked → bool
-
final
- latitude → double
-
final
- longitude → double
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited