SmartRoute class
Constructors
-
SmartRoute({required List<
LatLng> points, required double distanceMs, required Duration duration, required String encodedPolyline}) -
const
Properties
- distanceKm → double
-
no setter
- distanceMs → double
-
final
- duration → Duration
-
final
- encodedPolyline → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
points
→ List<
LatLng> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited